==> download.php?FileName=terralib-5.3.2.zip: share/terralib/translations/terralib_mod_qt_plugins_datasource_gdal_pt_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>GDALConnectorDialogForm</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="14"/>
        <source>GDAL Connector</source>
        <translation>Conector GDAL</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="39"/>
        <source>GDAL - Geospatial Data Abstraction Library</source>
        <translation>GDAL - Geospatial Data Abstraction Library</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="51"/>
        <source>&amp;Dataset access information</source>
        <translation>Informações de Acesso ao Banco de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="77"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="92"/>
        <source>File</source>
        <translation>Arquivo</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="102"/>
        <source>Directory</source>
        <translation>Diretório</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="112"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="124"/>
        <source>Data Source Title</source>
        <translation>Título da Fonte de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="134"/>
        <source>Data Source Description</source>
        <translation>Descrição da Fonte de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="153"/>
        <source>A more detailed description about the data source</source>
        <translation>Uma descrição mais detalhada sobre a fonte de dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="169"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="191"/>
        <source>&amp;Test</source>
        <translation>&amp;Teste</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="198"/>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="205"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::gdal::GDALConnector</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnector.cpp" line="74"/>
        <source>TerraLib Qt Components</source>
        <translation>Componentes TerraLib Qt</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnector.cpp" line="75"/>
        <source>Not implemented yet!
We will provide it soon!</source>
        <translation>Ainda não implementado!
Iremos fornecer em breve!</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::gdal::GDALConnectorDialog</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="152"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="159"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="183"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="189"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="195"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="231"/>
        <source>TerraLib Qt Components</source>
        <translation>Componentes TerraLib Qt</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="160"/>
        <source>Unknown error while opening dataset via GDAL!</source>
        <translation>Erro desconhecido durante abertura do conjunto de dados via GDAL !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="184"/>
        <source>Data source is ok!</source>
        <translation>Fonte de Dados está ok !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="196"/>
        <source>Unknown error while testing GDAL data source!</source>
        <translation>Erro desconhecido durante teste da fonte de dados GDAL !</translation>
    </message>
    <message>
        <source>Open Geo Spatial File</source>
        <translation type="vanished">Abrir Arquivo Geo Espacial</translation>
    </message>
    <message>
        <source>Image File (*.png *.jpg *.jpeg *.tif *.tiff *.geotif *.geotiff);; Web Map Service - WMS (*.xml *.wms);; Web Coverage Service - WCS (*.xml *.wcs);; All Files (*.*)</source>
        <translation type="vanished">Arquivo Imagem (*.png *.jpg *.jpeg *.tif *.tiff *.geotif *.geotiff);; Web Map Service - WMS (*.xml *.wms);; Web Coverage Service - WCS (*.xml *.wcs);; Todos Arquivos (*.*)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="219"/>
        <source>Select a directory with image files</source>
        <translation>Selecione um diretório com arquivos de imagem</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="232"/>
        <source>Sorry, network files are not implemented yet!
We will provide it soon!</source>
        <translation>Desculpe, arquivos de rede não estão implementados ainda !
Iremos fornecer em breve!</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::gdal::Plugin</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/Plugin.cpp" line="137"/>
        <source>Raster File...</source>
        <translation>Arquivo Matricial (raster)...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/Plugin.cpp" line="138"/>
        <source>Add new raster file as a layer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/Plugin.cpp" line="140"/>
        <source>RAW Raster File...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/Plugin.cpp" line="260"/>
        <source>Open Multiple Raster Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Raster File</source>
        <translation type="vanished">Arquivo Matricial (raster)</translation>
    </message>
    <message>
        <source>Error: there is no opened project!</source>
        <translation type="vanished">Erro: não há nenhum projeto aberto !</translation>
    </message>
    <message>
        <source>Open Raster File</source>
        <translation type="vanished">Abrir Arquivo Matricial (raster)</translation>
    </message>
</context>
</TS>

==> download.php?FileName=terralib-5.4.0.zip: share/terralib/translations/terralib_mod_qt_plugins_datasource_gdal_pt_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>GDALConnectorDialogForm</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="14"/>
        <source>GDAL Connector</source>
        <translation>Conector GDAL</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="39"/>
        <source>GDAL - Geospatial Data Abstraction Library</source>
        <translation>GDAL - Geospatial Data Abstraction Library</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="51"/>
        <source>&amp;Dataset access information</source>
        <translation>&amp;Informações de Acesso ao Banco de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="77"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="92"/>
        <source>File</source>
        <translation>Arquivo</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="102"/>
        <source>Directory</source>
        <translation>Diretório</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="112"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="124"/>
        <source>Data Source Title</source>
        <translation>Título da Fonte de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="134"/>
        <source>Data Source Description</source>
        <translation>Descrição da Fonte de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="153"/>
        <source>A more detailed description about the data source</source>
        <translation>Uma descrição mais detalhada sobre a fonte de dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="169"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="191"/>
        <source>&amp;Test</source>
        <translation>&amp;Teste</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="198"/>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/ui/GDALConnectorDialogForm.ui" line="205"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::gdal::GDALConnector</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnector.cpp" line="73"/>
        <source>TerraLib Qt Components</source>
        <translation>Componentes TerraLib Qt</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnector.cpp" line="74"/>
        <source>Not implemented yet!
We will provide it soon!</source>
        <translation>Ainda não implementado!
Iremos fornecer em breve!</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::gdal::GDALConnectorDialog</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="150"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="157"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="181"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="187"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="193"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="229"/>
        <source>TerraLib Qt Components</source>
        <translation>Componentes TerraLib Qt</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="158"/>
        <source>Unknown error while opening dataset via GDAL!</source>
        <translation>Erro desconhecido durante abertura do conjunto de dados via GDAL !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="182"/>
        <source>Data source is ok!</source>
        <translation>Fonte de Dados está ok !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="194"/>
        <source>Unknown error while testing GDAL data source!</source>
        <translation>Erro desconhecido durante teste da fonte de dados GDAL !</translation>
    </message>
    <message>
        <source>Open Geo Spatial File</source>
        <translation type="vanished">Abrir Arquivo Geo Espacial</translation>
    </message>
    <message>
        <source>Image File (*.png *.jpg *.jpeg *.tif *.tiff *.geotif *.geotiff);; Web Map Service - WMS (*.xml *.wms);; Web Coverage Service - WCS (*.xml *.wcs);; All Files (*.*)</source>
        <translation type="vanished">Arquivo Imagem (*.png *.jpg *.jpeg *.tif *.tiff *.geotif *.geotiff);; Web Map Service - WMS (*.xml *.wms);; Web Coverage Service - WCS (*.xml *.wcs);; Todos Arquivos (*.*)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="217"/>
        <source>Select a directory with image files</source>
        <translation>Selecione um diretório com arquivos de imagem</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/GDALConnectorDialog.cpp" line="230"/>
        <source>Sorry, network files are not implemented yet!
We will provide it soon!</source>
        <translation>Desculpe, arquivos de rede não estão implementados ainda !
Iremos fornecer em breve!</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::gdal::Plugin</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/Plugin.cpp" line="136"/>
        <source>Raster File...</source>
        <translation>Arquivo Matricial (raster)...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/Plugin.cpp" line="137"/>
        <source>Add new raster file as a layer.</source>
        <translation>Adicionar novo arquivo raster como um layer.</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/Plugin.cpp" line="139"/>
        <source>RAW Raster File...</source>
        <translation>RAW Arquivo Raster...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/gdal/Plugin.cpp" line="259"/>
        <source>Open Multiple Raster Files</source>
        <translation>Abrir múltiplos arquivos rasters</translation>
    </message>
    <message>
        <source>Raster File</source>
        <translation type="vanished">Arquivo Matricial (raster)</translation>
    </message>
    <message>
        <source>Error: there is no opened project!</source>
        <translation type="vanished">Erro: não há nenhum projeto aberto !</translation>
    </message>
    <message>
        <source>Open Raster File</source>
        <translation type="vanished">Abrir Arquivo Matricial (raster)</translation>
    </message>
</context>
</TS>
